/****************************************************************************
** Meta object code from reading C++ file 'kirigamiplasmafactory.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qqc2-breeze-style-6.7.2/kirigami-plasmadesktop-integration/kirigamiplasmafactory.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kirigamiplasmafactory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21KirigamiPlasmaFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto KirigamiPlasmaFactory::qt_create_metaobjectdata<qt_meta_tag_ZN21KirigamiPlasmaFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KirigamiPlasmaFactory"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KirigamiPlasmaFactory, qt_meta_tag_ZN21KirigamiPlasmaFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KirigamiPlasmaFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<Kirigami::Platform::PlatformPluginFactory::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KirigamiPlasmaFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KirigamiPlasmaFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21KirigamiPlasmaFactoryE_t>.metaTypes,
    nullptr
} };

void KirigamiPlasmaFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KirigamiPlasmaFactory *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KirigamiPlasmaFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KirigamiPlasmaFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KirigamiPlasmaFactoryE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.kde.kirigami.PlatformPluginFactory"))
        return static_cast< Kirigami::Platform::PlatformPluginFactory*>(this);
    return Kirigami::Platform::PlatformPluginFactory::qt_metacast(_clname);
}

int KirigamiPlasmaFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kirigami::Platform::PlatformPluginFactory::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_KirigamiPlasmaFactory[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x26,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'k',  'i',  'r',  'i',  'g', 
    'a',  'm',  'i',  '.',  'P',  'l',  'a',  't', 
    'f',  'o',  'r',  'm',  'P',  'l',  'u',  'g', 
    'i',  'n',  'F',  'a',  'c',  't',  'o',  'r', 
    'y', 
    // "className"
    0x03,  0x75,  'K',  'i',  'r',  'i',  'g',  'a', 
    'm',  'i',  'P',  'l',  'a',  's',  'm',  'a', 
    'F',  'a',  'c',  't',  'o',  'r',  'y', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(KirigamiPlasmaFactory, KirigamiPlasmaFactory, qt_pluginMetaDataV2_KirigamiPlasmaFactory)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_KirigamiPlasmaFactory[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x26,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'k',  'i',  'r',  'i',  'g', 
    'a',  'm',  'i',  '.',  'P',  'l',  'a',  't', 
    'f',  'o',  'r',  'm',  'P',  'l',  'u',  'g', 
    'i',  'n',  'F',  'a',  'c',  't',  'o',  'r', 
    'y', 
    // "className"
    0x03,  0x75,  'K',  'i',  'r',  'i',  'g',  'a', 
    'm',  'i',  'P',  'l',  'a',  's',  'm',  'a', 
    'F',  'a',  'c',  't',  'o',  'r',  'y', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(KirigamiPlasmaFactory, KirigamiPlasmaFactory)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
