/****************************************************************************
** Meta object code from reading C++ file 'iconlabellayout.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qqc2-breeze-style-6.7.2/style/impl/iconlabellayout.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'iconlabellayout.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15IconLabelLayoutE_t {};
} // unnamed namespace

template <> constexpr inline auto IconLabelLayout::qt_create_metaobjectdata<qt_meta_tag_ZN15IconLabelLayoutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IconLabelLayout",
        "QML.Element",
        "iconComponentChanged",
        "",
        "labelComponentChanged",
        "hasIconChanged",
        "hasLabelChanged",
        "iconChanged",
        "textChanged",
        "text",
        "fontChanged",
        "QFont",
        "font",
        "colorChanged",
        "iconRectChanged",
        "labelRectChanged",
        "availableWidthChanged",
        "availableHeightChanged",
        "spacingChanged",
        "topPaddingChanged",
        "leftPaddingChanged",
        "rightPaddingChanged",
        "bottomPaddingChanged",
        "mirroredChanged",
        "alignmentChanged",
        "displayChanged",
        "iconOnlyChanged",
        "textOnlyChanged",
        "textBesideIconChanged",
        "textUnderIconChanged",
        "relayout",
        "iconComponent",
        "QQmlComponent*",
        "labelComponent",
        "hasIcon",
        "hasLabel",
        "icon",
        "Breeze::QQuickIcon",
        "color",
        "QColor",
        "iconRect",
        "QRectF",
        "labelRect",
        "availableWidth",
        "availableHeight",
        "spacing",
        "leftPadding",
        "rightPadding",
        "topPadding",
        "bottomPadding",
        "mirrored",
        "alignment",
        "Qt::Alignment",
        "display",
        "Display",
        "iconOnly",
        "textOnly",
        "textBesideIcon",
        "textUnderIcon",
        "IconOnly",
        "TextOnly",
        "TextBesideIcon",
        "TextUnderIcon"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'iconComponentChanged'
        QtMocHelpers::SignalData<void()>(2, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelComponentChanged'
        QtMocHelpers::SignalData<void()>(4, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasIconChanged'
        QtMocHelpers::SignalData<void()>(5, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasLabelChanged'
        QtMocHelpers::SignalData<void()>(6, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(7, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(10, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(13, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconRectChanged'
        QtMocHelpers::SignalData<void()>(14, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelRectChanged'
        QtMocHelpers::SignalData<void()>(15, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableWidthChanged'
        QtMocHelpers::SignalData<void()>(16, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableHeightChanged'
        QtMocHelpers::SignalData<void()>(17, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spacingChanged'
        QtMocHelpers::SignalData<void()>(18, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topPaddingChanged'
        QtMocHelpers::SignalData<void()>(19, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftPaddingChanged'
        QtMocHelpers::SignalData<void()>(20, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightPaddingChanged'
        QtMocHelpers::SignalData<void()>(21, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomPaddingChanged'
        QtMocHelpers::SignalData<void()>(22, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mirroredChanged'
        QtMocHelpers::SignalData<void()>(23, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignmentChanged'
        QtMocHelpers::SignalData<void()>(24, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayChanged'
        QtMocHelpers::SignalData<void()>(25, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconOnlyChanged'
        QtMocHelpers::SignalData<void()>(26, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textOnlyChanged'
        QtMocHelpers::SignalData<void()>(27, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textBesideIconChanged'
        QtMocHelpers::SignalData<void()>(28, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textUnderIconChanged'
        QtMocHelpers::SignalData<void()>(29, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'relayout'
        QtMocHelpers::SlotData<void()>(30, 3, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'iconComponent'
        QtMocHelpers::PropertyData<QQmlComponent*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final | QMC::Required),
        // property 'labelComponent'
        QtMocHelpers::PropertyData<QQmlComponent*>(33, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final | QMC::Required),
        // property 'hasIcon'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'hasLabel'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'icon'
        QtMocHelpers::PropertyData<Breeze::QQuickIcon>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'iconRect'
        QtMocHelpers::PropertyData<QRectF>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 8),
        // property 'labelRect'
        QtMocHelpers::PropertyData<QRectF>(42, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 9),
        // property 'availableWidth'
        QtMocHelpers::PropertyData<qreal>(43, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 10),
        // property 'availableHeight'
        QtMocHelpers::PropertyData<qreal>(44, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 11),
        // property 'spacing'
        QtMocHelpers::PropertyData<qreal>(45, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 12),
        // property 'leftPadding'
        QtMocHelpers::PropertyData<qreal>(46, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 14),
        // property 'rightPadding'
        QtMocHelpers::PropertyData<qreal>(47, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 15),
        // property 'topPadding'
        QtMocHelpers::PropertyData<qreal>(48, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 13),
        // property 'bottomPadding'
        QtMocHelpers::PropertyData<qreal>(49, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 16),
        // property 'mirrored'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 17),
        // property 'alignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(51, 0x80000000 | 52, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 18),
        // property 'display'
        QtMocHelpers::PropertyData<enum Display>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 19),
        // property 'iconOnly'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 20),
        // property 'textOnly'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 21),
        // property 'textBesideIcon'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 22),
        // property 'textUnderIcon'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 23),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Display'
        QtMocHelpers::EnumData<enum Display>(54, 54, QMC::EnumFlags{}).add({
            {   59, Display::IconOnly },
            {   60, Display::TextOnly },
            {   61, Display::TextBesideIcon },
            {   62, Display::TextUnderIcon },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
    });
    return QtMocHelpers::metaObjectData<IconLabelLayout, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject IconLabelLayout::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15IconLabelLayoutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15IconLabelLayoutE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15IconLabelLayoutE_t>.metaTypes,
    nullptr
} };

void IconLabelLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IconLabelLayout *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->iconComponentChanged(); break;
        case 1: _t->labelComponentChanged(); break;
        case 2: _t->hasIconChanged(); break;
        case 3: _t->hasLabelChanged(); break;
        case 4: _t->iconChanged(); break;
        case 5: _t->textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->fontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 7: _t->colorChanged(); break;
        case 8: _t->iconRectChanged(); break;
        case 9: _t->labelRectChanged(); break;
        case 10: _t->availableWidthChanged(); break;
        case 11: _t->availableHeightChanged(); break;
        case 12: _t->spacingChanged(); break;
        case 13: _t->topPaddingChanged(); break;
        case 14: _t->leftPaddingChanged(); break;
        case 15: _t->rightPaddingChanged(); break;
        case 16: _t->bottomPaddingChanged(); break;
        case 17: _t->mirroredChanged(); break;
        case 18: _t->alignmentChanged(); break;
        case 19: _t->displayChanged(); break;
        case 20: _t->iconOnlyChanged(); break;
        case 21: _t->textOnlyChanged(); break;
        case 22: _t->textBesideIconChanged(); break;
        case 23: _t->textUnderIconChanged(); break;
        case 24: _t->relayout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::iconComponentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::labelComponentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::hasIconChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::hasLabelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::iconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)(const QString & )>(_a, &IconLabelLayout::textChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)(const QFont & )>(_a, &IconLabelLayout::fontChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::colorChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::iconRectChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::labelRectChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::availableWidthChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::availableHeightChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::spacingChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::topPaddingChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::leftPaddingChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::rightPaddingChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::bottomPaddingChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::mirroredChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::alignmentChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::displayChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::iconOnlyChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::textOnlyChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::textBesideIconChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconLabelLayout::*)()>(_a, &IconLabelLayout::textUnderIconChanged, 23))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlComponent**>(_v) = _t->iconComponent(); break;
        case 1: *reinterpret_cast<QQmlComponent**>(_v) = _t->labelComponent(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasIcon(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasLabel(); break;
        case 4: *reinterpret_cast<Breeze::QQuickIcon*>(_v) = _t->icon(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 6: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 8: *reinterpret_cast<QRectF*>(_v) = _t->iconRect(); break;
        case 9: *reinterpret_cast<QRectF*>(_v) = _t->labelRect(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->availableWidth(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->availableHeight(); break;
        case 12: *reinterpret_cast<qreal*>(_v) = _t->spacing(); break;
        case 13: *reinterpret_cast<qreal*>(_v) = _t->leftPadding(); break;
        case 14: *reinterpret_cast<qreal*>(_v) = _t->rightPadding(); break;
        case 15: *reinterpret_cast<qreal*>(_v) = _t->topPadding(); break;
        case 16: *reinterpret_cast<qreal*>(_v) = _t->bottomPadding(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->mirrored(); break;
        case 18: *reinterpret_cast<Qt::Alignment*>(_v) = _t->alignment(); break;
        case 19: *reinterpret_cast<enum Display*>(_v) = _t->display(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->iconOnly(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->textOnly(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->textBesideIcon(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->textUnderIcon(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIconComponent(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 1: _t->setLabelComponent(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 4: _t->setIcon(*reinterpret_cast<Breeze::QQuickIcon*>(_v)); break;
        case 5: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFont(*reinterpret_cast<QFont*>(_v)); break;
        case 7: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 12: _t->setSpacing(*reinterpret_cast<qreal*>(_v)); break;
        case 13: _t->setLeftPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 14: _t->setRightPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 15: _t->setTopPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 16: _t->setBottomPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 17: _t->setMirrored(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setAlignment(*reinterpret_cast<Qt::Alignment*>(_v)); break;
        case 19: _t->setDisplay(*reinterpret_cast<enum Display*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *IconLabelLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IconLabelLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15IconLabelLayoutE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int IconLabelLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void IconLabelLayout::iconComponentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IconLabelLayout::labelComponentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IconLabelLayout::hasIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IconLabelLayout::hasLabelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IconLabelLayout::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void IconLabelLayout::textChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void IconLabelLayout::fontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void IconLabelLayout::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void IconLabelLayout::iconRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void IconLabelLayout::labelRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void IconLabelLayout::availableWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void IconLabelLayout::availableHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void IconLabelLayout::spacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void IconLabelLayout::topPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void IconLabelLayout::leftPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void IconLabelLayout::rightPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void IconLabelLayout::bottomPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void IconLabelLayout::mirroredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void IconLabelLayout::alignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void IconLabelLayout::displayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void IconLabelLayout::iconOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void IconLabelLayout::textOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void IconLabelLayout::textBesideIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void IconLabelLayout::textUnderIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}
QT_WARNING_POP
