// /qt/qml/org/kde/breeze/Frame.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qalgorithms.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qrandom.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <cmath>
#include <limits>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_breeze_Frame_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0xd,0x0,0x0,0xee,0x7a,0x51,0x74,
0x38,0xf5,0x34,0x6,0x3c,0x39,0x81,0x1b,
0x9f,0x9,0x8a,0x43,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x2e,0x0,0x0,0x0,0x80,0x4,0x0,0x0,
0x7,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x26,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7c,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0xb,0x0,0x0,
0x80,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0xc0,0x2,0x0,0x0,0x20,0x3,0x0,0x0,
0x78,0x3,0x0,0x0,0xd0,0x3,0x0,0x0,
0x28,0x4,0x0,0x0,0x83,0x1,0x0,0x0,
0xa3,0x1,0x0,0x0,0xb3,0x1,0x0,0x0,
0xc3,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0xe3,0x1,0x0,0x0,0xd4,0x1,0x0,0x0,
0xf3,0x1,0x0,0x0,0x3,0x2,0x0,0x0,
0x94,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0x13,0x2,0x0,0x0,0x23,0x2,0x0,0x0,
0x33,0x2,0x0,0x0,0x83,0x1,0x0,0x0,
0x43,0x2,0x0,0x0,0xd4,0x1,0x0,0x0,
0x53,0x2,0x0,0x0,0x63,0x2,0x0,0x0,
0x94,0x1,0x0,0x0,0x53,0x0,0x0,0x0,
0x70,0x2,0x0,0x0,0x80,0x2,0x0,0x0,
0x53,0x0,0x0,0x0,0x70,0x2,0x0,0x0,
0x90,0x2,0x0,0x0,0x33,0x0,0x0,0x0,
0xa0,0x2,0x0,0x0,0xb0,0x2,0x0,0x0,
0x53,0x0,0x0,0x0,0x70,0x2,0x0,0x0,
0xc0,0x2,0x0,0x0,0x53,0x0,0x0,0x0,
0xa0,0x2,0x0,0x0,0xd4,0x2,0x0,0x0,
0x53,0x0,0x0,0x0,0x70,0x2,0x0,0x0,
0x90,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x68,0x0,0x0,0x0,0x37,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0xff,0xff,0xff,0xff,0x10,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2f,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x36,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2e,0x0,0x18,0x7,0x2e,0x1,0x18,0xc,
0x2e,0x2,0x80,0xc,0x18,0xd,0x2e,0x3,
0x80,0xd,0x18,0xa,0x2e,0x4,0x18,0xc,
0x2e,0x5,0x18,0xf,0xac,0x6,0xc,0x1,
0xf,0x18,0xc,0x2e,0x7,0x80,0xc,0x18,
0xd,0x2e,0x8,0x80,0xd,0x18,0xb,0xac,
0x9,0x7,0x2,0xa,0x18,0x6,0x2,0x0,
0x68,0x0,0x0,0x0,0x37,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0xff,0xff,0xff,0xff,0x10,0x0,0x0,0x0,
0xf,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2f,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x36,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2e,0xa,0x18,0x7,0x2e,0xb,0x18,0xc,
0x2e,0xc,0x80,0xc,0x18,0xd,0x2e,0xd,
0x80,0xd,0x18,0xa,0x2e,0xe,0x18,0xc,
0x2e,0xf,0x18,0xf,0xac,0x10,0xc,0x1,
0xf,0x18,0xc,0x2e,0x11,0x80,0xc,0x18,
0xd,0x2e,0x12,0x80,0xd,0x18,0xb,0xac,
0x13,0x7,0x2,0xa,0x18,0x6,0x2,0x0,
0x44,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x15,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x14,0x3c,0x15,
0x3c,0x16,0x18,0x7,0x2e,0x17,0x3c,0x18,
0x3c,0x19,0x80,0x7,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x18,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1a,0x3c,0x1b,
0x3c,0x1c,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x19,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1d,0x3c,0x1e,
0x3c,0x1f,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x1a,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x20,0x3c,0x21,
0x18,0x7,0xac,0x22,0x7,0x0,0x0,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1b,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x23,0x3c,0x24,
0x3c,0x25,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x5,0x0,0x0,0x40,0x5,0x0,0x0,
0x48,0x5,0x0,0x0,0x70,0x5,0x0,0x0,
0x88,0x5,0x0,0x0,0xb0,0x5,0x0,0x0,
0xc0,0x5,0x0,0x0,0xf0,0x5,0x0,0x0,
0x8,0x6,0x0,0x0,0x20,0x6,0x0,0x0,
0x40,0x6,0x0,0x0,0x80,0x6,0x0,0x0,
0xa8,0x6,0x0,0x0,0xe8,0x6,0x0,0x0,
0x0,0x7,0x0,0x0,0x38,0x7,0x0,0x0,
0x70,0x7,0x0,0x0,0x80,0x7,0x0,0x0,
0xb0,0x7,0x0,0x0,0xc8,0x7,0x0,0x0,
0xf8,0x7,0x0,0x0,0x10,0x8,0x0,0x0,
0x20,0x8,0x0,0x0,0x50,0x8,0x0,0x0,
0x70,0x8,0x0,0x0,0x80,0x8,0x0,0x0,
0x90,0x8,0x0,0x0,0xc8,0x8,0x0,0x0,
0xe0,0x8,0x0,0x0,0x0,0x9,0x0,0x0,
0x10,0x9,0x0,0x0,0x30,0x9,0x0,0x0,
0x50,0x9,0x0,0x0,0x70,0x9,0x0,0x0,
0xa8,0x9,0x0,0x0,0xc0,0x9,0x0,0x0,
0xe0,0x9,0x0,0x0,0x0,0xa,0x0,0x0,
0x20,0xa,0x0,0x0,0x40,0xa,0x0,0x0,
0x50,0xa,0x0,0x0,0x78,0xa,0x0,0x0,
0x98,0xa,0x0,0x0,0xa8,0xa,0x0,0x0,
0xd0,0xa,0x0,0x0,0xf0,0xa,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x54,0x0,0x65,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x73,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x4b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x62,0x0,0x72,0x0,
0x65,0x0,0x65,0x0,0x7a,0x0,0x65,0x0,
0x2e,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x54,0x0,0x2e,0x0,
0x46,0x0,0x72,0x0,0x61,0x0,0x6d,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x57,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x57,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x48,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x64,0x0,0x64,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x70,0x0,0x61,0x0,0x64,0x0,
0x64,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x49,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x2e,0x0,0x53,0x0,
0x74,0x0,0x61,0x0,0x6e,0x0,0x64,0x0,
0x61,0x0,0x72,0x0,0x64,0x0,0x52,0x0,
0x65,0x0,0x63,0x0,0x74,0x0,0x61,0x0,
0x6e,0x0,0x67,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x63,0x0,0x6f,0x0,0x6c,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x72,0x0,0x61,0x0,
0x64,0x0,0x69,0x0,0x75,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x72,0x0,0x61,0x0,0x64,0x0,
0x69,0x0,0x75,0x0,0x73,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x72,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x77,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x4d,0x0,0x61,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x6d,0x0,0x61,0x0,
0x78,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x42,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x57,0x0,0x69,0x0,0x64,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x6c,0x0,0x65,0x0,
0x66,0x0,0x74,0x0,0x49,0x0,0x6e,0x0,
0x73,0x0,0x65,0x0,0x74,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x72,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x49,0x0,
0x6e,0x0,0x73,0x0,0x65,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x63,0x0,0x65,0x0,
0x69,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x57,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6c,0x0,0x65,0x0,
0x66,0x0,0x74,0x0,0x50,0x0,0x61,0x0,
0x64,0x0,0x64,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x72,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x50,0x0,
0x61,0x0,0x64,0x0,0x64,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x42,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x48,0x0,0x65,0x0,0x69,0x0,0x67,0x0,
0x68,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x70,0x0,0x49,0x0,0x6e,0x0,0x73,0x0,
0x65,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6d,0x0,
0x49,0x0,0x6e,0x0,0x73,0x0,0x65,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x48,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x70,0x0,0x50,0x0,0x61,0x0,0x64,0x0,
0x64,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6d,0x0,
0x50,0x0,0x61,0x0,0x64,0x0,0x64,0x0,
0x69,0x0,0x6e,0x0,0x67,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x55,0x0,0x6e,0x0,
0x69,0x0,0x74,0x0,0x73,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x76,0x0,0x65,0x0,
0x72,0x0,0x79,0x0,0x4c,0x0,0x61,0x0,
0x72,0x0,0x67,0x0,0x65,0x0,0x53,0x0,
0x70,0x0,0x61,0x0,0x63,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x73,0x0,0x6d,0x0,
0x61,0x0,0x6c,0x0,0x6c,0x0,0x42,0x0,
0x6f,0x0,0x72,0x0,0x64,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x54,0x0,0x68,0x0,
0x65,0x0,0x6d,0x0,0x65,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x73,0x0,0x6d,0x0,
0x61,0x0,0x6c,0x0,0x6c,0x0,0x52,0x0,
0x61,0x0,0x64,0x0,0x69,0x0,0x75,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x73,0x0,0x65,0x0,
0x70,0x0,0x61,0x0,0x72,0x0,0x61,0x0,
0x74,0x0,0x6f,0x0,0x72,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x4c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x6,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x8,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x58,0x0,0x0,0x0,
0x10,0x1,0x0,0x0,0xb0,0x1,0x0,0x0,
0x7,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0xa,0x0,0x10,0x0,
0xb,0x0,0x50,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x17,0x0,0x50,0x0,
0x17,0x0,0x10,0x1,0xd,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x50,0x0,
0x15,0x0,0xe0,0x0,0xb,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x50,0x0,
0xf,0x0,0x50,0x1,0x9,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x50,0x0,
0xd,0x0,0x40,0x1,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9c,0x0,0x0,0x0,0x17,0x0,0x10,0x1,
0x0,0x0,0x0,0x0,0x9c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x90,0x0,
0x19,0x0,0x10,0x1,0x10,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x90,0x0,
0x18,0x0,0x0,0x1,0x14,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x90,0x0,
0x1a,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x1a,0x0,0x90,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1b,0x0,0x0,0x1,
0x1b,0x0,0x70,0x1,0x10,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x1,
0x1a,0x0,0x70,0x1,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitWidth at line 13, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
double v2_10;
double v2_14;
double v2_16;
double v2_24;
double v2_28;
double v2_35;
double v2_37;
double v2_41;
double v2_43;
double v2_47;
double v2_4;
double v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(1, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(2, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadScopeObjectPropertyLookup(2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_10 = (s.v2_4 + s.v2_8);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(3, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadScopeObjectPropertyLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_16 = (s.v2_10 + s.v2_14);
{
}
// generate_StoreReg
{
}
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(5, &s.v2_24)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
aotContext->initLoadScopeObjectPropertyLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_24;
s.v2_28 = (arg1 < 0.0 && arg1 > -1.0) ? std::copysign(0.0, -1.0) : std::ceil(arg1);
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(37);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(7, &s.v2_35)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(37);
#endif
aotContext->initLoadScopeObjectPropertyLookup(7);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_37 = (s.v2_28 + s.v2_35);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(43);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(8, &s.v2_41)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(43);
#endif
aotContext->initLoadScopeObjectPropertyLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_43 = (s.v2_37 + s.v2_41);
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_16;
const double arg2 = s.v2_43;
s.v2_47 = [&]() { 
auto  tmpMax = (qIsNull(arg2) && qIsNull(arg1) && std::copysign(1.0, arg2) == 1) ? arg2 : ((arg2 > arg1 || std::isnan(arg2)) ? arg2 : arg1);
return tmpMax;
}();
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_47;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitHeight at line 15, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
double v2_10;
double v2_14;
double v2_16;
double v2_24;
double v2_28;
double v2_35;
double v2_37;
double v2_41;
double v2_43;
double v2_47;
double v2_4;
double v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(11, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(12, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadScopeObjectPropertyLookup(12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_10 = (s.v2_4 + s.v2_8);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(13, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadScopeObjectPropertyLookup(13);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_16 = (s.v2_10 + s.v2_14);
{
}
// generate_StoreReg
{
}
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(15, &s.v2_24)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
aotContext->initLoadScopeObjectPropertyLookup(15);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_24;
s.v2_28 = (arg1 < 0.0 && arg1 > -1.0) ? std::copysign(0.0, -1.0) : std::ceil(arg1);
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(37);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(17, &s.v2_35)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(37);
#endif
aotContext->initLoadScopeObjectPropertyLookup(17);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_37 = (s.v2_28 + s.v2_35);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(43);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(18, &s.v2_41)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(43);
#endif
aotContext->initLoadScopeObjectPropertyLookup(18);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_43 = (s.v2_37 + s.v2_41);
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_16;
const double arg2 = s.v2_43;
s.v2_47 = [&]() { 
auto  tmpMax = (qIsNull(arg2) && qIsNull(arg1) && std::copysign(1.0, arg2) == 1) ? arg2 : ((arg2 > arg1 || std::isnan(arg2)) ? arg2 : arg1);
return tmpMax;
}();
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_47;
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for padding at line 21, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_10 = nullptr;
QObject *v2_2 = nullptr;
double v2_12;
double v2_14;
double v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadSingletonLookup(21, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadSingletonLookup(21, 5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(22, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(22, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_4 = double(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->loadSingletonLookup(24, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initLoadSingletonLookup(24, 5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->getObjectLookup(25, s.v2_10, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initGetObjectLookup(25, s.v2_10);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_12 = double(std::move(retrieved));
}
{
}
// generate_Add
s.v2_14 = (s.v2_4 + s.v2_12);
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_14;
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for color at line 24, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
QVariant v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadAttachedLookup(27, aotContext->qmlScopeObject, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadAttachedLookup(27, 3, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
s.v2_4 = QVariant(aotContext->lookupResultMetaType(28));
while (!aotContext->getObjectLookup(28, s.v2_2, s.v2_4.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(28, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_4 = QVariant(aotContext->lookupResultMetaType(28));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_4.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_4.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_4.data());
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for radius at line 25, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
double v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadSingletonLookup(30, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadSingletonLookup(30, 5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(31, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(31, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_4 = double(std::move(retrieved));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_4;
}
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for width at line 27, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
double v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadSingletonLookup(36, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadSingletonLookup(36, 5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(37, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(37, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_4 = double(std::move(retrieved));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_4;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
