/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<breezedial.h>)
#  include <breezedial.h>
#endif
#if __has_include(<iconlabellayout.h>)
#  include <iconlabellayout.h>
#endif
#if __has_include(<paintedsymbolitem.h>)
#  include <paintedsymbolitem.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_breeze_impl()
{
    qmlRegisterModule("org.kde.breeze.impl", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<BreezeDial>("org.kde.breeze.impl", 254);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.breeze.impl", 254);
    qmlRegisterTypesAndRevisions<IconLabelLayout>("org.kde.breeze.impl", 254);
    qmlRegisterEnum<IconLabelLayout::Display>("IconLabelLayout::Display");
    qmlRegisterTypesAndRevisions<PaintedSymbolItem>("org.kde.breeze.impl", 254);
    qmlRegisterEnum<PaintedSymbolItem::SymbolType>("PaintedSymbolItem::SymbolType");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.breeze.impl", 254, 254);
}

static const QQmlModuleRegistration orgkdebreezeimplRegistration("org.kde.breeze.impl", qml_register_types_org_kde_breeze_impl);
