/****************************************************************************
** Meta object code from reading C++ file 'breezedial.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qqc2-breeze-style-6.7.2/style/impl/breezedial.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'breezedial.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10BreezeDialE_t {};
} // unnamed namespace

template <> constexpr inline auto BreezeDial::qt_create_metaobjectdata<qt_meta_tag_ZN10BreezeDialE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BreezeDial",
        "QML.Element",
        "backgroundBorderColorChanged",
        "",
        "backgroundColorChanged",
        "fillBorderColorChanged",
        "fillColorChanged",
        "angleChanged",
        "grooveThicknessChanged",
        "notchesVisibleChanged",
        "backgroundBorderColor",
        "QColor",
        "backgroundColor",
        "fillBorderColor",
        "fillColor",
        "angle",
        "grooveThickness",
        "notchesVisible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'backgroundBorderColorChanged'
        QtMocHelpers::SignalData<void()>(2, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void()>(4, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillBorderColorChanged'
        QtMocHelpers::SignalData<void()>(5, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillColorChanged'
        QtMocHelpers::SignalData<void()>(6, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'angleChanged'
        QtMocHelpers::SignalData<void()>(7, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grooveThicknessChanged'
        QtMocHelpers::SignalData<void()>(8, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'notchesVisibleChanged'
        QtMocHelpers::SignalData<void()>(9, 3, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'backgroundBorderColor'
        QtMocHelpers::PropertyData<QColor>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'fillBorderColor'
        QtMocHelpers::PropertyData<QColor>(13, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'fillColor'
        QtMocHelpers::PropertyData<QColor>(14, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'angle'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'grooveThickness'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'notchesVisible'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
    });
    return QtMocHelpers::metaObjectData<BreezeDial, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BreezeDial::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BreezeDialE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BreezeDialE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10BreezeDialE_t>.metaTypes,
    nullptr
} };

void BreezeDial::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BreezeDial *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->backgroundBorderColorChanged(); break;
        case 1: _t->backgroundColorChanged(); break;
        case 2: _t->fillBorderColorChanged(); break;
        case 3: _t->fillColorChanged(); break;
        case 4: _t->angleChanged(); break;
        case 5: _t->grooveThicknessChanged(); break;
        case 6: _t->notchesVisibleChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BreezeDial::*)()>(_a, &BreezeDial::backgroundBorderColorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BreezeDial::*)()>(_a, &BreezeDial::backgroundColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BreezeDial::*)()>(_a, &BreezeDial::fillBorderColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BreezeDial::*)()>(_a, &BreezeDial::fillColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BreezeDial::*)()>(_a, &BreezeDial::angleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BreezeDial::*)()>(_a, &BreezeDial::grooveThicknessChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BreezeDial::*)()>(_a, &BreezeDial::notchesVisibleChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->backgroundBorderColor(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->fillBorderColor(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->fillColor(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->angle(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->grooveThickness(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->notchesVisible(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBackgroundBorderColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setFillBorderColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setFillColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setAngle(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setGrooveThickness(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setNotchesVisible(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BreezeDial::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BreezeDial::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BreezeDialE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int BreezeDial::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void BreezeDial::backgroundBorderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BreezeDial::backgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BreezeDial::fillBorderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BreezeDial::fillColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BreezeDial::angleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BreezeDial::grooveThicknessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void BreezeDial::notchesVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
